@@ -8,18 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cloudwatch-auto-retention",
-    "0.0.3",
+    "0.0.4",
     __name__[0:-6],
-    "cloudwatch-auto-retention@0.0.3.jsii.tgz",
+    "cloudwatch-auto-retention@0.0.4.jsii.tgz",
 )
 
 __all__ = [
